unshortenit
===========

Unshortens ad-based urls and 301 redirects. Supports adf.ly, adfoc.us, and sh.st.

Features
--------

- Supports unshortening the following ad-based shortners:
	- Adf.ly and related subdomains
	- Sh.st
	- Adfoc.us
- Supports any 301 redirected urls
- Meta Refresh redirected urls
- Python 3.5+ support only

Usage
-----

Documentation for this library can be found [here](http://unshortenit.readthedocs.io/en/latest/)